<?php

namespace Drupal\ckeditor_templates_ui\Form;

use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Entity\EntityTypeManager;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Implement config form for Ckeditor template.
 */
class CkeditorTemplateForm extends EntityForm {

  /**
   * {@inheritdoc}
   */
  public function __construct(EntityTypeManager $entityTypeManager) {
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);

    $template = $this->entity;

    $form['label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Title'),
      '#default_value' => $template->label(),
      '#description' => $this->t('Your Template title'),
      '#required' => TRUE,
    ];
    $form['id'] = [
      '#type' => 'machine_name',
      '#default_value' => $template->id(),
      '#machine_name' => [
        'exists' => [$this, 'exist'],
      ],
      '#disabled' => !$template->isNew(),
      '#required' => TRUE,
    ];
    $form['description'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Description'),
      '#default_value' => $template->getDescription(),
      '#description' => $this->t('Your Template description'),
    ];
    // $form['image'] = [
    //   '#title' => t('Upload an image file for this template'),
    //   '#type' => 'managed_file',
    //   '#upload_location' => 'public://ckeditor-templates/',
    //   '#multiple' => FALSE,
    //   '#description' => t('Allowed extensions: gif png jpg jpeg'),
    //   '#upload_validators' => [
    //     'file_validate_is_image' => array(),
    //     'file_validate_extensions' => array('gif png jpg jpeg'),
    //     'file_validate_size' => array(25600000),
    //   ],
    // ];
    $form['html'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Body'),
      '#description' => $this->t('The predefined ckeditor template body'),
      '#required' => TRUE,
    ];
    if (!$template->isNew()) {
      // $form['image']['#default_value'] = [$template->image];
      $form['html']['#format'] = $template->getHtml()['format'];
      $form['html']['#default_value'] = $template->getHtml()['value'];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $template = $this->entity;

    // Set image real value instead of array
    // $template->image = reset($template->image);
    $status = $template->save();

    if ($status) {
      drupal_set_message($this->t('Saved the %label Ckeditor Template.', [
        '%label' => $template->label(),
      ]));
    }
    else {
      drupal_set_message($this->t('The %label Ckeditor Template was not saved.', [
        '%label' => $template->label(),
      ]));
    }

    $form_state->setRedirect('entity.ckeditor_template.collection');
  }

  /**
   * Helper function to check if ckeditor_template configuration entity exists.
   */
  public function exist($id) {
    $entity = $this->entityTypeManager->getStorage('ckeditor_template')->getQuery()
      ->condition('id', $id)
      ->execute();
    return (bool) $entity;
  }

}
